<?php
/**
 * Add Note capability to dokuwiki
 * <note>This is note</note>
 * <note classic>This is note</note>
 * <note important>This is an important note</note>
 * <note warning>This is a big warning</note>
 * <note tip>This is a tip</note>
 *
 * HIGHLY derived from the work of :
 * Stephane Chamberland <stephane.chamberland@ec.gc.ca> (Side Notes PlugIn)
 * Carl-Christian Salvesen <calle@ioslo.net> (Graphviz plugin)
 * Olivier Cortes <olivier.cortes@ryxeo.com> (Original note plugin)
 * Modified by Eric Hameleers to use <div> instead of <table> and to
 *   contain the images and stylesheet inside the plugin.
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author     Eric Hameleers <alien@slackware.com>
 */
 
if(!defined('DOKU_INC')) define('DOKU_INC',realpath(dirname(__FILE__).'/../../').'/');
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'syntax.php');


/**
 * All DokuWiki plugins to extend the parser/rendering mechanism
 * need to inherit from this class
 */
class syntax_plugin_note extends DokuWiki_Syntax_Plugin {
 
    function getInfo(){
        return array(
            'author' => 'Eric Hameleers',
            'email'  => 'alien@slackware.com',
            'date'   => '2006-03-24',
            'name'   => 'Note Plugin',
            'desc'   => 'Add Note/Important/Tip/Warning Capability (DIV+CSS box)',
            'url'    => 'http://wiki.splitbrain.org/plugin:note',
        );
    }
 
 
    function getType(){ return 'container'; }
 
    function getPType(){ return 'normal'; }

    function getAllowedTypes() { return array('container','substition','protected','disabled','formatting','paragraphs'); }
 
    function getSort(){
        return 195;
    }

    // override default accepts() method to allow nesting 
    // - ie, to get the plugin accepts its own entry syntax
    function accepts($mode) {
      if ($mode == substr(get_class($this), 7)) return true;
        return parent::accepts($mode);
      }

    /**
     * Connect pattern to lexer
     */
    function connectTo($mode) {
        $this->Lexer->addEntryPattern('<note.*?>(?=.*?\x3C/note\x3E)',$mode,'plugin_note');
    }
    function postConnect() {
        $this->Lexer->addExitPattern('</note>','plugin_note');
    }

 
    /**
     * Handle the match
     */
    function handle($match, $state, $pos, &$handler){
        switch ($state) {
          case DOKU_LEXER_ENTER :
            $notetype = trim(substr($match, 5, -1));
            return array($state, $notetype);
          case DOKU_LEXER_UNMATCHED :
            return array($state, $match);
          case DOKU_LEXER_EXIT :
            return array($state, '');
        }
        return array();
    }
 
 
    /**
     * Create output
     */
    function render($mode, &$renderer, $data) {
        if($mode == 'xhtml'){
          list($state, $match) = $data;
          switch ($state) {
            case DOKU_LEXER_ENTER :
              if ( $match == 'important' || $match == 'important' ) {
                $css_class = "noteimportant";
              }
              else if ($match == 'warning' || $match == 'bloquante' || $match == 'critique' ) {
                $css_class = "notewarning";
              }
              else if ($match == 'tip' || $match == 'tuyau' || $match == 'idee') {
                $css_class = "notetip";
              }
              else if ( $match == '' || $match == 'classic' || $match == 'classique' ){
                $css_class = "noteclassic";
              }
              else {
                // Fall back to at least a distinct dokuwiki style:
                $css_class = "info";
              }
              $renderer->doc .= "</p><div class=\"" . $css_class . "\">\n";
              break;
  
            case DOKU_LEXER_UNMATCHED :
              //$renderer->doc .= $renderer->_xmlEntities($match);
              $renderer->doc .= $match;
              break;
  
            case DOKU_LEXER_EXIT :
              $renderer->doc .= "\n</div><p>";
              break;
          }
          return true;
        }
        return false;
    }
 
}
 
//Setup VIM: ex: et ts=4 enc=utf-8 :
?>
